@@ -26,16 +26,16 @@ model.fit(X_train, Y_train)
 
 Y_predict = model.predict(X_test)
 
-def greet(Age, time, ejection_fraction, serum_creatinine):
+def calculate(Age, time, ejection_fraction, serum_creatinine):
     
     test = [[Age, time, ejection_fraction, serum_creatinine]]
     test = pd.DataFrame(test, columns =['age', 'ejection_fraction','serum_creatinine','time'], dtype = float)
-
-        
     return int(model.predict(test))
 
-iface = gr.Interface(
-  fn=greet, 
-  inputs=[gr.inputs.Slider(0, 100), gr.inputs.Slider(0, 300), gr.inputs.Slider(0, 80), gr.inputs.Slider(0, 10)],
-  outputs=["number"])
-iface.launch(share=True)
\ No newline at end of file
+
+def hlaunch():
+    iface = gr.Interface(
+    fn=calculate,
+    inputs=[gr.inputs.Slider(0, 100), gr.inputs.Slider(0, 300), gr.inputs.Slider(0, 80), gr.inputs.Slider(0, 10)],
+    outputs=["number"])
+  iface.launch(share=True)
\ No newline at end of file
